import { Context } from 'koa';
import { OSS } from 'aliyun-sdk';
import config from '../../config';
import * as busboy from 'async-busboy';
import * as mime from 'mime';
import * as uuid from 'uuid';
import { S3Client }from '@aws-sdk/client-s3';
import { Upload } from '@aws-sdk/lib-storage';
import { Readable } from 'stream';

const S3 = new S3Client({
    region: 'us-east-1',
    endpoint: config.OSS.OSS_ENDPOINT,
    credentials: {
      accessKeyId: config.OSS.OSS_ACCESS_ID,
      secretAccessKey: config.OSS.OSS_ACCESS_KEY
    },
    forcePathStyle: true
});


export const UploadImage = async (ctx: Context) => {
    console.log('start update file')
    try {
        const uploadFiles: { fieldname: string, file: Readable, fname: string, encoding: string, mimeType: string }[] = []
        const results: any[] = [];
        const waitForUploads: Promise<any>[] = [];
        const filesToUpload: Readable[] = [];
        await busboy(ctx.req, {
            onFile: async(fieldname, _file, fname, encoding, mimeType) => {
                const file = _file as unknown as Readable; // wrong type in dts
                file.pause();
                console.log(`Will upload ${fname}`);
                uploadFiles.push({ fieldname, file, fname, encoding, mimeType });
                const ext = mime['extension'](mimeType) || "x";

                if (['png', 'jpg', 'jpeg', 'gif', 'webp'].indexOf(ext) === -1) {
                    throw new Error('Unsupported image type');
                }
                const filename = `avatars/${uuid.v1()}.${ext}`;
                console.log(`uploading ${fname} to ${filename}`)
                const upload = new Upload({
                    client: S3,
                    params: {
                        Bucket: config.OSS.OSS_BUCKET,
                        Key: filename,
                        ContentType: mimeType,
                        Body: file
                    }
                })
                waitForUploads.push(upload.done());
                results.push({ Key: filename });
            }
        });
        console.log(`waiting`);
        filesToUpload.forEach((file) => file.resume());
        await Promise.all(waitForUploads);
        console.log(`finish`);
        ctx.body = results;
    } catch (err) {
        ctx.throw(403, err);
    }
};
